Oodle

Struct Oodle 

pub struct Oodle { /* private fields */ }
Oodle compression library loaded at runtime.

Implementations

Source

impl Oodle

pub fn load(path: impl AsRef<OsStr>) -> Result<Self, Error>

Load the Oodle shared library from the given path.

pub fn compress( &self, compressor: OodleCompressor, level: OodleCompressionLevel, input: &[u8], output: &mut [u8], ) -> Result<usize, Error>

Compress input into output using the given compressor and level.

Returns the number of bytes written to output.

pub fn decompress(&self, source: &[u8], dest: &mut [u8]) -> Result<usize, Error>

Decompress source into dest with default options.

Returns the number of decompressed bytes written to dest.

pub fn decompress_with_options( &self, source: &[u8], dest: &mut [u8], fuzz_safe: OodleFuzzSafe, check_crc: OodleCheckCrc, verbosity: OodleVerbosity, thread_phase: OodleDecodeThreadPhase, ) -> Result<usize, Error>

Decompress source into dest with explicit options.

Returns the number of decompressed bytes written to dest.

pub fn get_compressed_buffer_size_needed( &self, compressor: OodleCompressor, raw_size: usize, ) -> usize

Returns the buffer size needed to hold the compressed output for the given compressor and raw data size.

pub fn get_decode_buffer_size( &self, compressor: OodleCompressor, raw_size: usize, corruption_possible: bool, ) -> usize

Returns the buffer size needed for decompression, optionally accounting for possible data corruption.

pub fn get_compress_scratch_mem_bound( &self, compressor: OodleCompressor, level: OodleCompressionLevel, raw_len: usize, ) -> usize

Returns the scratch memory size bound needed for compression.